@@ -99,13 +99,18 @@ def checkup_workspacedir( ) :
 
 def handle_key_fromcontainer( ) :
     
+
+    if( get_key( "endpoint/key" ) ) :
+        return
+
     if not "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" in os.environ : return
 
     endpoint_key = os.environ[ "_CONTAINER_LOCAL_CONFIGENDPOINTKEY" ]
 
     if endpoint_key.endswith( "_LOCAL_CONFIGENDPOINTKEY_" ) : return
 
-    set_key_alt( "endpoint/key" , endpoint_key ) 
+    #set_key_alt( "endpoint/key" , endpoint_key ) 
+    set_key( "endpoint/key" , endpoint_key ) 
 
 
 
