@@ -72,8 +72,10 @@ def json_save( fn , data ) :
     with open( fn , "w" ) as file:
         file.write( json_encode( data) )
 
-
-
+def json_load( fn ) :
+    with open( fn ) as f :
+        j = json.load( f )
+    return( j )
 
 #####################################################################
 
@@ -438,4 +440,7 @@ def file_getcontent( fn , scp ) :
     return( contents )
 
 
+def path_stem( p ) :
+    fn=Path(p).stem
+    return(fn)
 
