@@ -51,6 +51,9 @@ def defdata( ) :
 def defmeta( ) :
     return( s_db.meta_read( "_meta" ) )
 
+def flush( ) :
+    return( s_db.flush( ) )
+
 def uptime( ) :
     return( s_util.uptime( ) )
 def uptime_lap( ) :
@@ -181,6 +184,10 @@ def run( params = { } , wait_timeout = 60 ) :
 
     #####################################################################
 
+    #s_db.flush( ) 
+
+    #####################################################################
+
     s_db.meta_create( "_params" , params )
 
     #####################################################################
